<p align="center">
  <a href="https://millerships.github.io/pyznn/"><img src="https://millerships.github.io/pyznn/img/logo.svg" alt="PyZNN"></a>
</p>
<p align="center">
    <em>Python SDK for interacting with the Zenon network and ecosystem.</em>
</p>

---

**Documentation**: <a href="https://millerships.github.io/pyznn/" target="_blank">https://millerships.github.io/pyznn</a>

**Source Code**: <a href="https://github.com/millerships/pyznn/" target="_blank">https://github.com/millerships/pyznn</a>

---

## Installation

### Requirements

- Python 3.7 or above

```bash
pip install pyznn
```

## Contributing

Head over to <a href="https://millerships.github.io/pyznn/docs/contributing" target="_blank">Contributing docs</a>.

## Sponsors

This project was sponsored by <a href="https://medium.com/@zenon.network/hyperspace-x-accelerator-z-towards-a-dao-of-daos-38dfad496365" target="_blank">Accelerator-Z</a>
